@@ -17,7 +17,7 @@ use futures::future::BoxFuture;
 use std::collections::BTreeSet;
 use std::panic;
 use std::path::PathBuf;
-use tempfile::{tempdir, TempDir};
+use tempfile::{TempDir, tempdir};
 
 #[tokio::test]
 async fn read_length_from_valid_string() {
@@ -95,7 +95,7 @@ where
     let mut test_root = UnixPathBuf::from(response.trim_end_matches('\n'));
     test_root.push("mozdevice");
 
-    let _ = device.remove(&test_root);
+    let _ = device.remove(&test_root).await;
 
     // TODO: we've removed panic::catch_unwind here, if the test crashes the forwarding isn't cleaned up
     let _result = test(&device, &tmp_dir, &test_root).await;
@@ -515,7 +515,7 @@ async fn device_push_pull_large_binary_file() {
 
                 // Needs to be larger than 64kB to test multiple chunks.
                 for i in 0..100000u32 {
-                    content.push('0' as u8 + (i % 10) as u8);
+                    content.push(b'0' + (i % 10) as u8);
                 }
 
                 device
@@ -569,7 +569,7 @@ async fn device_push_permission() {
                     // Convert the mode integer into the string representation
                     // of the mode returned by `ls`. This assumes the object is
                     // a file and not a directory.
-                    let mut perms = vec!["-", "r", "w", "x", "r", "w", "x", "r", "w", "x"];
+                    let mut perms = ["-", "r", "w", "x", "r", "w", "x", "r", "w", "x"];
                     let mut bit_pos = 0;
                     while bit_pos < 9 {
                         if (1 << bit_pos) & mode == 0 {
@@ -654,7 +654,7 @@ async fn device_push_and_list_dir() {
                 }
 
                 device
-                    .push_dir(tmp_dir.path(), &remote_root_path, 0o777)
+                    .push_dir(tmp_dir.path(), remote_root_path, 0o777)
                     .await
                     .expect("to push_dir");
 
@@ -669,7 +669,7 @@ async fn device_push_and_list_dir() {
                 }
 
                 let mut listings = device
-                    .list_dir(&remote_root_path)
+                    .list_dir(remote_root_path)
                     .await
                     .expect("to list_dir");
                 listings.sort();
@@ -747,7 +747,7 @@ async fn device_push_and_pull_dir() {
                 }
 
                 device
-                    .push_dir(&src_dir, &remote_root_path, 0o777)
+                    .push_dir(&src_dir, remote_root_path, 0o777)
                     .await
                     .expect("to push_dir");
 
@@ -784,7 +784,7 @@ async fn device_push_and_list_dir_flat() {
                 ];
 
                 for file in files.iter() {
-                    let path = tmp_dir.path().join(&file);
+                    let path = tmp_dir.path().join(file);
                     let _ = std::fs::create_dir_all(path.parent().unwrap());
 
                     let f = File::create(path).await.expect("to create file");
@@ -795,7 +795,7 @@ async fn device_push_and_list_dir_flat() {
                 }
 
                 device
-                    .push_dir(tmp_dir.path(), &remote_root_path, 0o777)
+                    .push_dir(tmp_dir.path(), remote_root_path, 0o777)
                     .await
                     .expect("to push_dir");
 
@@ -810,7 +810,7 @@ async fn device_push_and_list_dir_flat() {
                 }
 
                 let mut listings = device
-                    .list_dir_flat(&remote_root_path, 7, "prefix".to_string())
+                    .list_dir_flat(remote_root_path, 7, "prefix".to_string())
                     .await
                     .expect("to list_dir_flat");
                 listings.sort();
